==> react-native-common-ui-0.1.3.tgz: package/js/Components/Switch.js <==
import React from 'react';
import { Switch as RCTSwitch, View } from 'react-native';
import { CheckBox } from '../Basics/CheckBox';
import { Touchable } from '../Basics/Index';
import { Radio } from '../Basics/Radio';
import { useTheme } from '../Hooks/Theme';
export const Switch = (props) => {
    const { value, type, children, onSwitch, theme, subtle, variant } = props;
    const config = useTheme(theme);
    const colorSet = subtle ? config.color.subtle : config.color.main;
    const color = colorSet[variant];
    switch (type) {
        case 'checkbox':
            return (React.createElement(Touchable, { style: {
                    flexDirection: 'row',
                    alignItems: 'center'
                }, onPress: onSwitch },
                React.createElement(CheckBox, { checked: value, width: 24, height: 24, color: color.content, style: {
                        marginRight: 4
                    } }),
                children));
        case 'radio':
            return (React.createElement(Touchable, { style: {
                    flexDirection: 'row',
                    alignItems: 'center'
                }, onPress: onSwitch },
                React.createElement(Radio, { checked: value, width: 24, height: 24, color: color.content, style: {
                        marginRight: 4
                    } }),
                children));
        case 'toggle':
            return (React.createElement(View, { style: {
                    flexDirection: 'row',
                    alignItems: 'center'
                } },
                React.createElement(RCTSwitch, { value: value, onValueChange: onSwitch, trackColor: {
                        true: color.content,
                        false: colorSet.separator.border
                    }, style: {
                        marginRight: 4
                    } }),
                children));
        default:
            return null;
    }
};

==> react-native-common-ui-0.1.7.tgz: package/js/Components/Switch.js <==
import React from 'react';
import { Switch as RCTSwitch, View } from 'react-native';
import { CheckBox } from '../Basics/CheckBox';
import { Touchable } from '../Basics/Index';
import { Radio } from '../Basics/Radio';
import { useTheme } from '../Hooks/Theme';
export const Switch = (props) => {
    const { value, type, children, onSwitch, theme, subtle, variant } = props;
    const config = useTheme(theme);
    const colorSet = subtle ? config.color.subtle : config.color.main;
    const color = colorSet[variant];
    switch (type) {
        case 'checkbox':
            return (React.createElement(Touchable, { style: {
                    flexDirection: 'row',
                    alignItems: 'center'
                }, onPress: onSwitch },
                React.createElement(CheckBox, { checked: value, width: 24, height: 24, color: color.content, style: {
                        marginRight: 4
                    } }),
                children));
        case 'radio':
            return (React.createElement(Touchable, { style: {
                    flexDirection: 'row',
                    alignItems: 'center'
                }, onPress: onSwitch },
                React.createElement(Radio, { checked: value, width: 24, height: 24, color: color.content, style: {
                        marginRight: 4
                    } }),
                children));
        case 'toggle':
            return (React.createElement(View, { style: {
                    flexDirection: 'row',
                    alignItems: 'center'
                } },
                React.createElement(RCTSwitch, { value: value, onValueChange: onSwitch, thumbColor: colorSet.separator.surface, trackColor: {
                        true: color.content,
                        false: colorSet.separator.border
                    }, style: {
                        marginRight: 4
                    } }),
                children));
        default:
            return null;
    }
};
